$VERSION = '1.00';
# -*- Perl -*-
#############################################################################
# Written by Tim Skirvin <tskirvin@killfile.org>.
# Copyright 2001 Tim Skirvin.  Redistribution terms are below.
#############################################################################

=head1 NAME

CGI::NoForm - Give text equivalents of CGI form entries

=head1 SYNOPSIS

  use CGI::NoForm;
  my $cgi  = new CGI;
  my $cgi2 = new CGI::NoForm;
  print $cgi->textfield('Test', "testing");
  print $cgi2->textfield('Test', "testing");

This should show the differences between a regular CGI and a NoForm CGI.
Usage information is below. 

=head1 DESCRIPTION

This module offers functions that convert standard form entries into text
without requiring the use of a web browser.  This is handy for many reasons, 
not the least of which is being able to print out forms that look nice on
your browser, but otherwise don't work so well.  It is a superset of the
standard CGI module.

=cut

package CGI::NoForm;

use strict;
use CGI;

use vars qw( @ISA );
@ISA = "CGI";

=head1 USAGE

Most of these functions operate in the same way as their equivalent C<CGI>
function; they just return a slightly different value. 

=over 2

=item isindex, startform, start_multipart_form, endform, end_multiport_form 

=item submit, reset, defaults, comment, hidden, button, image_button

All of these items return an empty string ("").  They make no sense out of 
the context of a form.

=cut

sub isindex              { "" }	
sub startform            { "" }	
sub start_multipart_form { "" }
sub endform              { "" }
sub end_multipart_form   { "" }
sub submit               { "" }	
sub reset                { "" }
sub defaults             { "" }
sub comment 		 { "" }
sub hidden 	         { "" }
sub button               { "" }
sub image_button         { "" }

=item textfield, password_field, filefield

Return the 'blahblah' out of 'value="blahblah"'.

=cut

# Return the blahblah of 'value="blahblah"'
sub textfield {
  my $self = shift;
  my $ret = CGI->textfield(@_);
  $ret =~ s/^.*(?:value="([^"]*)").*$/$1/i;
  $ret || "";
}
sub password_field        { textfield(@_) }
sub filefield             { textfield(@_)  }

=item textarea 

Returns the text between the <textarea> tags.

=cut

sub textarea { 
  my $self = shift;
  my $ret = CGI->textarea(@_);
  $ret =~ s%^<textarea.*>(.*)</textarea>$%$1%i;
  $ret || "";
}

=item popup_menu, scrolling_list

Clears out the select statements, and only returns the 'selected' option
tag.

=cut

sub popup_menu {
  my $self = shift;  my $ret = CGI->popup_menu(@_);
  my @lines = split("\n", $ret);

  # Clear out select statements and option tags
  map { s/^<select name=".*".*>|<\/select>$//g; } @lines ;
  map { s/^<option  .*>.*<\/option>$//g; } @lines ;
  map { s/<option selected value=(.*)>(.*)<\/option>$/$2/g; } @lines;
  	   # $2 || $1 /egx; } @lines;
  	   # $3 ? $3 : $2 /exg; } @lines;

  wantarray ? @lines : join("\n", @lines);
}
sub scrolling_list    { popup_menu(@_) }

=item checkbox, checkbox_group, 

If 'item1' is checked and 'item2' is not, returns this:

  [X] item1 
  [ ] item2

=cut

sub checkbox {
  my $self = shift;  my $ret = CGI->checkbox(@_);
  _checked($ret);
}
sub checkbox_group {
  my $self = shift;  my @ret = CGI->checkbox_group(@_);
  map { _checked($_) } @ret; 
  wantarray ? @ret : join(' ', @ret);
}

=item radio_group 

Returns the item of the radio group that would have been selected.

=cut

sub radio_group { 
  my $self = shift;  my @ret = CGI->radio_group(@_);
  foreach (@ret) {
    my $val = _checked($_);
    if ($val =~ /^\[X\] (.*)$/) { return $1 } 
  }
  return "";
}

=back

Any remaining functions are the same as in C<CGI>.

=cut

### _checked ( LINE )
# Does the work of checkbox, checkbox_group, and radio_group
sub _checked {
  my $line = shift;
  my $checked = 1 if ($line =~ /^<input.*checked.*>[^<>]*$/);
  my $value = "";
  if ($line =~ m/^<input.*>([^<>]*)$/i) { $value = $1 }
  return "" unless $value;
  $checked ? "[X] $value" : "[ ] $value";
}

=head1 REQUIREMENTS

Perl 5 or better, and the CGI module.

=head1 SEE ALSO

L<CGI>

=head1 NOTES 

There are some more CGI functions that could probably be duplicated.  All
in all, this is really pretty basic; it might be best integrated into the
main CGI module.

=head1 AUTHOR

Tim Skirvin (tskirvin@killfile.org)

=head1 COPYRIGHT

Copyright 2001 by Tim Skirvin (tskirvin@killfile.org)  This code may be
redistributed under the same terms as Perl itself.

=cut

1;

### VERSION HISTORY ###########################################################
## v1.00 - Wed Mar 21 14:52:57 CST 2001
# Basic infrastructure and setup, with documentation.  That was a quick
#   development process...
